@@ -1,6 +1,6 @@
 #' Combines two vectors of alleles when alleles are character vectors.
 #'
-## Copyright(c) 2017-2020 R. Mark Sharp
+## Copyright(c) 2017-2024 R. Mark Sharp
 ## This file is part of nprcgenekeepr
 #' Combines two vectors by randomly selecting one allele
 #' or the other at each position. Alleles may be of any class that
@@ -16,7 +16,8 @@
 #' @param a2 vector with second parent alleles for each individual
 #' \code{a1} and \code{a2} are equal length vectors of alleles for one
 #' individual
+#' @noRd
 chooseAllelesChar <- function(a1, a2) {
-  s <- sample(1:(2 * length(a1)), length(a1), replace = FALSE)
-  return(c(a1, a2)[s])
+  s <- sample.int((2L * length(a1)), length(a1), replace = FALSE)
+  c(a1, a2)[s]
 }
