@@ -1,25 +1,24 @@
 #' Converts status indicators to a Standardized code
 #'
-## Copyright(c) 2017-2020 R. Mark Sharp
+## Copyright(c) 2017-2024 R. Mark Sharp
 ## This file is part of nprcgenekeepr
 #' Part of Pedigree Curation
 #'
 #' @return A factor vector of the standardized status codes with levels:
 #' `ALIVE`, `DECEASED`, `SHIPPED`, and `UNKNOWN`.
 #'
-#' @examples
-#' \donttest{
-#' library(nprcgenekeepr)
-#' original <- c("A", "alive", "Alive", "1", "S", "Sale", "sold", "shipped",
-#'               "D", "d", "dead", "died", "deceased", "2",
-#'               "shiped", "3", "U", "4", "unknown", NA,
-#'               "Unknown", "H", "hermaphrodite", "U", "Unknown", "4")
-#' convertStatusCodes(original)
-#' }
-#'
 #' @param status character vector or NA. Flag indicating an individual's
 #' status as alive, dead, sold, etc.
 #' @export
+#' @examples
+#' library(nprcgenekeepr)
+#' original <- c(
+#'   "A", "alive", "Alive", "1", "S", "Sale", "sold", "shipped",
+#'   "D", "d", "dead", "died", "deceased", "2",
+#'   "shiped", "3", "U", "4", "unknown", NA,
+#'   "Unknown", "H", "hermaphrodite", "U", "Unknown", "4"
+#' )
+#' convertStatusCodes(original)
 convertStatusCodes <- function(status) {
   status <- toupper(status)
   status[is.na(status)] <- "UNKNOWN"
@@ -29,7 +28,9 @@ convertStatusCodes <- function(status) {
     "SHIPPED"
   status[status %in% c("UNKNOWN", "U", "4")] <- "UNKNOWN"
 
-  status <- factor(status, levels = c("ALIVE", "DECEASED", "SHIPPED",
-                                      "UNKNOWN"))
-  return(status)
+  status <- factor(status, levels = c(
+    "ALIVE", "DECEASED", "SHIPPED",
+    "UNKNOWN"
+  ))
+  status
 }
