@@ -1,6 +1,6 @@
 #' getChangedColsTab skeleton of list of errors
 #'
-## Copyright(c) 2017-2020 R. Mark Sharp
+## Copyright(c) 2017-2024 R. Mark Sharp
 ## This file is part of nprcgenekeepr
 #'
 #' @return HTML formatted error list
@@ -9,6 +9,8 @@
 #' @param pedigreeFileName name of file provided by user on Input tab
 #' @export
 getChangedColsTab <- function(errorLst, pedigreeFileName) {
-  tabPanel("Changed Columns",
-           div(HTML(insertChangedColsTab(errorLst, pedigreeFileName))))
+  tabPanel(
+    "Changed Columns",
+    div(HTML(insertChangedColsTab(errorLst, pedigreeFileName)))
+  )
 }
