@@ -1,6 +1,6 @@
 #' Get proportion of Low genetic value animals
 #'
-## Copyright(c) 2017-2020 R. Mark Sharp
+## Copyright(c) 2017-2024 R. Mark Sharp
 ## This file is part of nprcgenekeepr
 #'
 #' @return List of the proportion of Low genetic value animals and the
@@ -10,19 +10,20 @@
 #' is to have already been filtered to remove animals that should not be
 #' included in the calculation.
 #' @importFrom stringi stri_detect_fixed
+#' @noRd
 getProportionLow <- function(geneticValues) {
   proportion <-
     length(geneticValues[stri_detect_fixed(geneticValues, "Low")]) /
-    length(geneticValues)
+      length(geneticValues)
   if (proportion > 0.5) {
     color <- "red"
-    colorIndex <- 1
-  } else if (proportion <= 0.5 & proportion >= 0.3) {
+    colorIndex <- 1L
+  } else if (proportion <= 0.5 && proportion >= 0.3) {
     color <- "yellow"
-    colorIndex <- 2
-  }else if (proportion < 0.3) {
+    colorIndex <- 2L
+  } else if (proportion < 0.3) {
     color <- "green"
-    colorIndex <- 3
+    colorIndex <- 3L
   }
   list(proportion = proportion, color = color, colorIndex = colorIndex)
 }
