@@ -1,6 +1,6 @@
 #' Returns record numbers with selected \code{recordStatus}.
 #'
-## Copyright(c) 2017-2020 R. Mark Sharp
+## Copyright(c) 2017-2024 R. Mark Sharp
 ## This file is part of nprcgenekeepr
 #'
 #' @return An integer vector of records with \code{recordStatus} ==
@@ -9,9 +9,11 @@
 #' @param ped pedigree dataframe
 #' @param status character vector with value of \code{"added"} or
 #' \code{"original"}.
+#' @noRd
 getRecordStatusIndex <- function(ped, status = "added") {
-  if (any("recordStatus" %in% names(ped)))
+  if (any("recordStatus" %in% names(ped))) {
     seq_along(ped$recordStatus)[ped$recordStatus == status]
-  else
-    integer(0)
+  } else {
+    integer(0L)
+  }
 }
