@@ -1,6 +1,6 @@
 #' Updates list of available animals by removing the selected animal
 #'
-## Copyright(c) 2017-2020 R. Mark Sharp
+## Copyright(c) 2017-2024 R. Mark Sharp
 ## This file is part of nprcgenekeepr
 #'
 #' @return list of available animals
@@ -8,9 +8,10 @@
 #' @param available list of available animals for each group
 #' @param ids character vector having the selected animal Ids
 #' @param numGp integer indicating the number of groups being formed.
-removeSelectedAnimalFromAvailableAnimals <- function(available, ids, numGp) {
+#' @noRd
+removeSelectedAnimalFromAvailableAnimals <- function(available, ids, numGp) { # nolint: object_length_linter
   # Remove the selected animal from consideration
-  for (j in 1:numGp) {
+  for (j in 1L:numGp) {
     available[[j]] <- setdiff(available[[j]], ids)
   }
   available
