@@ -1,9 +1,11 @@
 #' Returns a logical vector with results of stri_detect() for each pattern in
 #' second parameters character vector.
-## Copyright(c) 2017-2020 R. Mark Sharp
+## Copyright(c) 2017-2024 R. Mark Sharp
 ## This file is part of nprcgenekeepr
 #'
 #' @usage str_detect_fixed_all(strings, patterns, ignore_na, ...)
+#' @return logical vector with results of stri_detect() for each pattern in
+#' the character vector in the parameter \code{patterns}.
 #' @param strings input vector. This must be an atomic vector and will be
 #' coerced to a character vector.
 #' @param patterns patterns to look for, as defined by a POSIX regular
@@ -14,11 +16,13 @@
 #' \code{patterns} before comparison
 #' @param ... further arguments for stri_detect_fixed
 #' @importFrom stringi stri_detect_fixed
+#' @noRd
 str_detect_fixed_all <- function(strings, patterns, ignore_na = FALSE, ...) {
   if (ignore_na) {
     strings <- strings[!is.na(strings)]
     patterns <- patterns[!is.na(patterns)]
   }
   vapply(patterns, function(pattern) {
-    any(stri_detect_fixed(strings, pattern, ...))}, logical(1))
+    any(stri_detect_fixed(strings, pattern, ...))
+  }, logical(1L))
 }
