@@ -1,12 +1,12 @@
-#' Copyright(c) 2017-2020 R. Mark Sharp
+#' Copyright(c) 2017-2024 R. Mark Sharp
 #' This file is part of nprcgenekeepr
 context("countLoops")
-library(testthat)
+
 ped <- nprcgenekeepr::qcPed
-ped <- qcStudbook(ped, minParentAge = 0)
+ped <- qcStudbook(ped, minParentAge = 0L)
 pedTree <- createPedTree(ped)
 pedLoops <- findLoops(pedTree)
 test_that("countLoops correctly counts loops", {
   nLoops <- countLoops(pedLoops, pedTree)
-  expect_equal(sum(unlist(nLoops[nLoops > 0])), 45)
+  expect_equal(sum(unlist(nLoops[nLoops > 0L])), 45L)
 })
