@@ -1,4 +1,4 @@
-#' Copyright(c) 2017-2020 R. Mark Sharp
+#' Copyright(c) 2017-2024 R. Mark Sharp
 #' This file is part of nprcgenekeepr
 context("filterReport")
 library(testthat)
@@ -6,9 +6,9 @@ library(testthat)
 rpt <- nprcgenekeepr::pedWithGenotypeReport$report
 test_that("filterReport correctly subsets reports based on provide IDs", {
   rpt1 <- filterReport(c("GHH9LB", "BD41WW"), rpt)
-  expect_equal(nrow(rpt1), 2)
+  expect_identical(nrow(rpt1), 2L)
   rpt1 <- filterReport(c(), rpt)
-  expect_equal(nrow(rpt1), 0)
+  expect_identical(nrow(rpt1), 0L)
   rpt1 <- filterReport(rpt$id, rpt)
-  expect_equal(nrow(rpt1), nrow(rpt))
+  expect_identical(nrow(rpt1), nrow(rpt))
 })
