@@ -1,4 +1,4 @@
-#' Copyright(c) 2017-2020 R. Mark Sharp
+#' Copyright(c) 2017-2024 R. Mark Sharp
 # This file is part of nprcgenekeepr
 context("makeRelationsClasses")
 library(testthat)
@@ -6,7 +6,8 @@ suppressMessages(library(dplyr))
 
 qcPed <- nprcgenekeepr::qcPed
 bkmat <- kinship(qcPed$id, qcPed$sire, qcPed$dam, qcPed$gen,
-                 sparse = FALSE)
+  sparse = FALSE
+)
 kin <- convertRelationships(bkmat, qcPed)
 relClasses <- as.data.frame(makeRelationClassesTable(kin))
 relClasses$`Relationship Class` <- as.character(relClasses$`Relationship Class`)
@@ -14,8 +15,10 @@ relClassTbl <- kin[!kin$relation == "Self", ] %>%
   group_by(relation) %>%
   summarise(count = n())
 test_that("makeRelationsClasses retains the correct counts", {
-  for (rel in relClasses[ , "Relationship Class"]) {
-    expect_equal(relClasses$Frequency[relClasses$`Relationship Class` == rel],
-                 relClassTbl$count[relClassTbl$relation == rel])
+  for (rel in relClasses[, "Relationship Class"]) {
+    expect_identical(
+      relClasses$Frequency[relClasses$`Relationship Class` == rel],
+      relClassTbl$count[relClassTbl$relation == rel]
+    )
   }
 })
