@@ -1,4 +1,4 @@
-#' Copyright(c) 2017-2020 R. Mark Sharp
+#' Copyright(c) 2017-2024 R. Mark Sharp
 # This file is part of nprcgenekeepr
 context("print.summary.nprcgenekeeprGV")
 library(testthat)
@@ -8,8 +8,8 @@ test_that("print.summary.nprcgenekeeprGV prints expected output", {
   ped$birth_date[ped$ego_id == "d2"] <- "2000-04-13"
   ped$birth_date[ped$ego_id == "o4"] <- "2016-04-13"
   ped <- suppressWarnings(qcStudbook(ped, reportErrors = FALSE))
-  summaryGV <- summary(reportGV(ped, guIter = 10))
+  summaryGV <- summary(reportGV(ped, guIter = 10L))
   expect_success(expect_output(print(summaryGV)))
-  expect_equal(summaryGV[1], c("The genetic value report"))
-  expect_equal(length(summaryGV), 8)
+  expect_identical(summaryGV[1L], "The genetic value report")
+  expect_length(summaryGV, 8L)
 })
